clear all
set memory 500000
set more off, perm
cap log close

use "NunnWantchekon_Dataset", clear

sum age age2 male urban_dum education employment religion living_conditions district_ethnic_frac frac_ethnicity_in_district country malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum v30 v33
sum exports ln_exports export_area ln_export_area export_pop ln_export_pop


***************
* REPLICATION *
***************

global baseline_controls "age age2 male urban_dum i.education i.employment i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.country"
global colonial_controls "malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum i.v30 v33"


*** Table 1: Trust Relatives 

* Only clustering-adjusted SE and 2-way clustering-adjusted SE are computed here.

matrix table1 = J(8,6,.)
matrix colnames table1 = exports export_area export_pop ln_export ln_export_area ln_export_pop 
matrix rownames table1 = coefficient cluster_se 2waycluster_se conley_se n_obs n_ethn n_distr r_squared

*** Slave exports only ***
qui xi: reg trust_relatives exports $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,1]=B[1,1]
mat table1[2,1]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,1]=obs
mat table1[6,1]=ethn
mat table1[8,1]=r2
qui xi: cgmreg trust_relatives exports $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,1]=sqrt(V[1,1])
qui xi: reg trust_relatives exports $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,1]=distr

*** Slave exports/land area ***
qui xi: reg trust_relatives export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,2]=B[1,1]
mat table1[2,2]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,2]=obs
mat table1[6,2]=ethn
mat table1[8,2]=r2
qui xi: cgmreg trust_relatives export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,2]=sqrt(V[1,1])
qui xi: reg trust_relatives export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,2]=distr

*** slave exports/historic pop ***
qui xi: reg trust_relatives export_pop $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,3]=B[1,1]
mat table1[2,3]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,3]=obs
mat table1[6,3]=ethn
mat table1[8,3]=r2
qui xi: cgmreg trust_relatives export_pop $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,3]=sqrt(V[1,1])
qui xi: reg trust_relatives export_pop $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,3]=distr

*** Ln slave exports only ***
qui xi: reg trust_relatives ln_exports $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,4]=B[1,1]
mat table1[2,4]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,4]=obs
mat table1[6,4]=ethn
mat table1[8,4]=r2
qui xi: cgmreg trust_relatives ln_exports $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,4]=sqrt(V[1,1])
qui xi: reg trust_relatives ln_exports $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,4]=distr

*** ln slave exports/land area ***
qui xi: reg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,5]=B[1,1]
mat table1[2,5]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,5]=obs
mat table1[6,5]=ethn
mat table1[8,5]=r2
qui xi: cgmreg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,5]=sqrt(V[1,1])
qui xi: reg trust_relatives ln_export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,5]=distr

*** ln slave exports/historic pop ***
qui xi: reg trust_relatives ln_export_pop $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat V=e(V)
mat table1[1,6]=B[1,1]
mat table1[2,6]=sqrt(V[1,1])
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table1[5,6]=obs
mat table1[6,6]=ethn
mat table1[8,6]=r2
qui xi: cgmreg trust_relatives ln_export_pop $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table1[3,6]=sqrt(V[1,1])
qui xi: reg trust_relatives ln_export_pop $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table1[7,6]=distr

di "Table 1 - Dependent Variable: Trust of Relatives"
mat list table1

*** Table 2: Trust in relatives, people you know, local council, other people from your country.

matrix table2 = J(6,4,.)
matrix colnames table2 = relatives peopleyouknow local_council other_yourcountry 
matrix rownames table2 = coefficient 2waycluster_se n_obs n_ethn n_distr r_squared

*** Trust in relatives

qui xi: reg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat table2[1,1]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table2[3,1]=obs
mat table2[4,1]=ethn
mat table2[6,1]=r2

qui xi: cgmreg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table2[2,1]=sqrt(V[1,1])
qui xi: reg trust_relatives ln_export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table2[5,1]=scalar(distr)

*** Trust in people you know

qui xi: reg trust_peopleyouknow ln_export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat table2[1,2]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table2[3,2]=obs
mat table2[4,2]=ethn
mat table2[6,2]=r2

qui xi: cgmreg trust_peopleyouknow ln_export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table2[2,2]=sqrt(V[1,1])
qui xi: reg trust_peopleyouknow ln_export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table2[5,2]=scalar(distr)


*** Trust in local council

qui xi: reg trust_local_council ln_export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat table2[1,3]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table2[3,3]=obs
mat table2[4,3]=ethn
mat table2[6,3]=r2

qui xi: cgmreg trust_local_council ln_export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table2[2,3]=sqrt(V[1,1])
qui xi: reg trust_local_council ln_export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table2[5,3]=scalar(distr)


*** Trust in other people in your country
qui xi: reg trust_nationals ln_export_area $baseline_controls, cluster(murdock_name)
mat B=e(b)
mat table2[1,4]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table2[3,4]=obs
mat table2[4,4]=ethn
mat table2[6,4]=r2

qui xi: cgmreg trust_nationals ln_export_area $baseline_controls, cluster(murdock_name district)
mat V=e(V)
mat table2[2,4]=sqrt(V[1,1])
qui xi: reg trust_nationals ln_export_area $baseline_controls, cluster(district)
scalar distr=e(N_clust)
mat table2[5,4]=scalar(distr)

mat list table2


*** Table 3: Additional Controls

matrix table3 = J(6,4,.)
matrix colnames table3 = relatives peopleyouknow local_council other_yourcountry 
matrix rownames table3 = coefficient 2waycluster_se n_obs n_ethn n_distr r_squared

*** Trust relatives
qui xi: reg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
mat B=e(b)
mat table3[1,1]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table3[3,1]=obs
mat table3[4,1]=ethn
mat table3[6,1]=r2

qui xi: cgmreg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
mat V=e(V)
mat table3[2,1]=sqrt(V[1,1])
qui xi: reg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar distr=e(N_clust)
mat table3[5,1]=scalar(distr)

*** Trust other people you know
qui xi: reg trust_peopleyouknow ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
mat B=e(b)
mat table3[1,2]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table3[3,2]=obs
mat table3[4,2]=ethn
mat table3[6,2]=r2

qui xi: cgmreg trust_peopleyouknow ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
mat V=e(V)
mat table3[2,2]=sqrt(V[1,1])
qui xi: reg trust_peopleyouknow ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar distr=e(N_clust)
mat table3[5,2]=scalar(distr)

*** Trust local council
qui xi: reg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
mat B=e(b)
mat table3[1,3]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table3[3,3]=obs
mat table3[4,3]=ethn
mat table3[6,3]=r2

qui xi: cgmreg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
mat V=e(V)
mat table3[2,3]=sqrt(V[1,1])
qui xi: reg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar distr=e(N_clust)
mat table3[5,3]=scalar(distr)


*** Trust other people in your country
qui xi: reg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
mat B=e(b)
mat table3[1,4]=B[1,1]
scalar obs=e(N)
scalar ethn=e(N_clust)
scalar r2=e(r2)
mat table3[3,4]=obs
mat table3[4,4]=ethn
mat table3[6,4]=r2

qui xi: cgmreg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
mat V=e(V)
mat table3[2,4]=sqrt(V[1,1])
qui xi: reg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar distr=e(N_clust)
mat table3[5,4]=scalar(distr)

mat list table3

*** Table 4: Assessing bias from unobservables

matrix table4=J(4,4,.)
matrix colnames table4= trust_relatives trust_peopleyouknow trust_local_council trust_nationals

set varabbrev off
preserve
foreach trustvariable in trust_relatives trust_peopleyouknow trust_local_council trust_nationals {
	di in yellow "`trustvariable'"
	scalar colnum=colnumb(table4,"`trustvariable'")

	*** Rows #1 & #3 ***
	* Full #1
	quietly xi: reg `trustvariable' ln_export_area $baseline_controls, cluster(murdock_name)
	predict hat if e(sample), xb
	scalar beta3=_b[ln_export_area]
	* Unrestricted #1
	quietly xi: reg `trustvariable' ln_export_area i.country if missing(hat)!=1, cluster(murdock_name)
	scalar beta1=_b[ln_export_area]
	* Unrestricted #2
	quietly xi: reg `trustvariable' ln_export_area i.country age age2 male if missing(hat)!=1, cluster(murdock_name)
	scalar beta2=_b[ln_export_area]
	* Row 1
	scalar diff1_3=beta3/(beta1-beta3)
	mat table4[1,colnum]=diff1_3
	* Row 3
	scalar diff2_3=beta3/(beta2-beta3)
	mat table4[3,colnum]=diff2_3
	drop hat
	mat list table4
	
	*** Rows #2 & #4 ***
	* Full #2
	quietly xi: reg `trustvariable' ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
	predict hat if e(sample), xb
	scalar beta5=_b[ln_export_area]
	* Unrestricted #1
	quietly xi: reg `trustvariable' ln_export_area i.country if missing(hat)!=1, cluster(murdock_name)
	scalar beta1=_b[ln_export_area]
	* Unrestricted #2
	quietly xi: reg `trustvariable' ln_export_area i.country age age2 male if missing(hat)!=1, cluster(murdock_name)
	scalar beta2=_b[ln_export_area]
	* Row 2
	scalar diff1_5=beta5/(beta1-beta5)
	mat table4[2,colnum]=diff1_5
	* Row 4
	scalar diff2_5=beta5/(beta2-beta5)
	mat table4[4,colnum]=diff2_5
	drop hat
	mat list table4
}
	
*** Table 5: IV estimates using historic distance to coast

/*
***********************************
*** Code for Clustering by Hand ***
***********************************
quietly xi: ivreg trust_relatives (ln_export_area=distsea) $baseline_controls $colonial_controls, cluster(murdock_name)
matrix vc1 = e(V)
quietly xi: ivreg trust_relatives (ln_export_area=distsea) $baseline_controls $colonial_controls, cluster(district)
matrix vc2 = e(V)

quietly gen bc3=murdock_name+"_"+district
quietly xi: ivreg trust_relatives (ln_export_area=distsea) $baseline_controls $colonial_controls, cluster(bc3)
quietly matrix vc=vc1+vc2-e(V)
quietly gen se=sqrt(vc[1,1])
tab se
quietly drop se
***********************************
*/

*******************************************************************************
*** Table 5, Cols 1-5: Controlling for pre-colonial population density only ***
*******************************************************************************
quietly gen bc3=murdock_name+"_"+district

matrix table5=J(11,4,.)
matrix colnames table5= trust_relatives trust_peopleyouknow trust_local_council trust_nationals
matrix rownames table5= export_area SE_export Hausman_pvalue Rsquared distance_coast SE_distance observations ethnicities districts Fstat Rsquared_firststage

foreach trustvariable of varlist trust_relatives trust_peopleyouknow trust_local_council trust_nationals{
********************
di "`trustvariable'"	/* Just so we know which variable in loop */
********************
scalar colnum=colnumb(table5,"`trustvariable'")

* IV-estimate
xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name) 
matrix vc1 = e(V)
matrix beta_iv = e(b)
scalar coeff_iv=beta_iv[1,1]
matrix table5[1,colnum]=scalar(coeff_iv)
scalar r2 = e(r2)
matrix table5[4,colnum]=scalar(r2)
scalar obs=e(N)
matrix table5[7,colnum]=scalar(obs)
scalar ethn=e(N_clust)
matrix table5[8,colnum]=scalar(ethn)

* OLS-estimate
quietly xi: cgmreg `trustvariable' ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
matrix vc_ols = e(V)
matrix beta_ols = e(b)

/* DWH Test & first stage F-stat */
quietly xi: reg ln_export_area distsea $baseline_controls $colonial_controls ln_init_pop_density if missing(`trustvariable')~=1, cluster(murdock_name)
scalar coeff_firststage=_b[distsea]
matrix table5[5,colnum]=scalar(coeff_firststage)
matrix vce_firststage=e(V)
matrix table5[6,colnum]=sqrt(vce_firststage[1,1])
scalar r2firststage=e(r2)
matrix table5[11,colnum]=scalar(r2firststage)

*F-test
test distsea==0
scalar fstat=r(F)
matrix table5[10,colnum]=scalar(fstat)

*** Doing the 2-way clustering by hand ***
* vc1 obtained earlier.
quietly xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
matrix vc2 = e(V)
scalar dist=e(N_clust)
matrix table5[9,colnum]=scalar(dist)

quietly xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density, cluster(bc3)
matrix vc3=e(V)
matrix vc=vc1+vc2-vc3

*calculate hausman statistic
scalar coeff_iv = beta_iv[1,1]
scalar coeff_ols = beta_ols[1,1]
scalar var_iv = vc[1,1]
matrix table5[2,colnum] = sqrt(vc[1,1])

scalar var_ols = vc_ols[1,1]
scalar hausmanstat = (coeff_iv - coeff_ols)^2 / (var_iv - var_ols)
scalar pvalue = 1-chi2(1,hausmanstat)
di "HAUSMAN P-VALUE: " pvalue
matrix table5[3,colnum]=pvalue
}

mat list table5

****************************************
* Table 6: IV with additional controls *
****************************************

matrix table6=J(11,4,.)
matrix colnames table6= trust_relatives trust_peopleyouknow trust_local_council trust_nationals
matrix rownames table6= export_area SE_export Hausman_pvalue Rsquared distance_coast SE_distance observations ethnicities districts Fstat Rsquared_firststage

foreach trustvariable of varlist trust_relatives trust_peopleyouknow trust_local_council trust_nationals{
********************
di "`trustvariable'"	/* Just so we know which variable in loop */
********************
scalar colnum=colnumb(table5,"`trustvariable'")

xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density fishing dist_Saharan_node dist_Saharan_line, cluster(murdock_name) 
matrix vc1 = e(V)
matrix beta_iv = e(b)
scalar coeff_iv=beta_iv[1,1]
matrix table6[1,colnum]=scalar(coeff_iv)
scalar r2 = e(r2)
matrix table6[4,colnum]=scalar(r2)
scalar obs=e(N)
matrix table6[7,colnum]=scalar(obs)
scalar ethn=e(N_clust)
matrix table6[8,colnum]=scalar(ethn)

quietly xi: cgmreg `trustvariable' ln_export_area $baseline_controls $colonial_controls ln_init_pop_density fishing dist_Saharan_node dist_Saharan_line, cluster(murdock_name district)
matrix vc_ols = e(V)
matrix beta_ols = e(b)

/* DWH Test & first stage F-stat */
quietly xi: reg ln_export_area distsea $baseline_controls $colonial_controls ln_init_pop_density fishing dist_Saharan_node dist_Saharan_line if missing(`trustvariable')~=1, cluster(murdock_name)
scalar coeff_firststage=_b[distsea]
matrix table6[5,colnum]=scalar(coeff_firststage)
matrix vce_firststage=e(V)
matrix table6[6,colnum]=sqrt(vce_firststage[1,1])
scalar r2firststage=e(r2)
matrix table6[11,colnum]=scalar(r2firststage)

*F-test
test distsea==0
scalar fstat=r(F)
matrix table6[10,colnum]=scalar(fstat)

*** Doing the 2-way clustering by hand ***
* vc1 obtained earlier.
quietly xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density fishing dist_Saharan_node dist_Saharan_line, cluster(district)
matrix vc2 = e(V)
scalar dist=e(N_clust)
matrix table6[9,colnum]=scalar(dist)

quietly xi: ivreg `trustvariable' (ln_export_area=distsea) $baseline_controls $colonial_controls ln_init_pop_density fishing dist_Saharan_node dist_Saharan_line, cluster(bc3)
matrix vc3=e(V)
matrix vc=vc1+vc2-vc3

*calculate hausman statistic
scalar coeff_iv = beta_iv[1,1]
scalar coeff_ols = beta_ols[1,1]
scalar var_iv = vc[1,1]
matrix table6[2,colnum] = sqrt(vc[1,1])

scalar var_ols = vc_ols[1,1]
scalar hausmanstat = (coeff_iv - coeff_ols)^2 / (var_iv - var_ols)
scalar pvalue = 1-chi2(1,hausmanstat)
di "HAUSMAN P-VALUE: " pvalue
matrix table6[3,colnum]=pvalue
}

mat list table6

* For Table 7 and 8 Nunn and Wantchekon also use the Asiabarometer and WVS datasets.
* Since we do not consider extra datasources, we only replicate the results based on Afrobarometer data.

***************
*** Table 7 ***
***************

matrix table7=J(5,2,.)
matrix colnames table7= Afro_1 Afro_2
matrix rownames table7= distancecoast SE observations clusters Rsquared

xi: reg trust_local_council distsea i.country if missing(religion)!=1 & missing(urban_dum)!=1 & missing(male)!=1 & missing(age)!=1, cluster(murdock_name)
scalar coeff_dist=_b[distsea]
matrix V=e(V)
matrix table7[1,1]=scalar(coeff_dist)
matrix table7[2,1]=sqrt(V[1,1])
scalar obs=e(N)
matrix table7[3,1]=scalar(obs)
scalar clusters=e(N_clust)
matrix table7[4,1]=scalar(clusters)
scalar r2=e(r2)
matrix table7[5,1]=scalar(r2)

xi: reg trust_local_council distsea age age2 male urban_dum i.religion i.country, cluster(murdock_name)
scalar coeff_dist=_b[distsea]
matrix V=e(V)
matrix table7[1,2]=scalar(coeff_dist)
matrix table7[2,2]=sqrt(V[1,1])
scalar obs=e(N)
matrix table7[3,2]=scalar(obs)
scalar clusters=e(N_clust)
matrix table7[4,2]=scalar(clusters)
scalar r2=e(r2)
matrix table7[5,2]=scalar(r2)

mat list table7

*************
** Table 8 **
*************
matrix table8=J(5,2,.)
matrix colnames table8= Afro_1 Afro_2
matrix rownames table8= distancecoast SE observations clusters Rsquared

*Nunn and Wantchekon use "inter-group trust", which is not available in AB2008 hence we use "trust other people in your country"

xi: reg trust_nationals distsea i.country if missing(urban_dum)!=1 & missing(male)!=1 & missing(age)!=1, cluster(murdock_name)
scalar coeff_dist=_b[distsea]
matrix V=e(V)
matrix table8[1,1]=scalar(coeff_dist)
matrix table8[2,1]=sqrt(V[1,1])
scalar obs=e(N)
matrix table8[3,1]=scalar(obs)
scalar clusters=e(N_clust)
matrix table8[4,1]=scalar(clusters)
scalar r2=e(r2)
matrix table8[5,1]=scalar(r2)

xi: reg trust_nationals distsea age age2 male urban_dum i.country, cluster(murdock_name)
scalar coeff_dist=_b[distsea]
matrix V=e(V)
matrix table8[1,2]=scalar(coeff_dist)
matrix table8[2,2]=sqrt(V[1,1])
scalar obs=e(N)
matrix table8[3,2]=scalar(obs)
scalar clusters=e(N_clust)
matrix table8[4,2]=scalar(clusters)
scalar r2=e(r2)
matrix table8[5,2]=scalar(r2)

mat list table8

***************
*** Table 9 ***
***************

matrix table9=J(8,5,.)
matrix colnames table9= localcouncil_1 localcouncil_2 within_town within_district within_prov
matrix rownames table9= exports SE_exports exp_otherethn SE_exp_otherethn observations ethnicities districts Rsquared

matrix t9nocontrols=J(8,5,.)
matrix colnames t9nocontrols= localcouncil_1 localcouncil_2 within_town within_district within_prov
matrix rownames t9nocontrols= exports SE_exports exp_otherethn SE_exp_otherethn observations ethnicities districts Rsquared


global publicgoods "school_present electricity_present piped_water_present sewage_present health_clinic_present"
global qualitylocalgovt "i.local_council_performance i.council_listen i.corrupt_local_council"

*************************************************
*** Test #1: Local Council Trust (Cols 1 & 2) ***
*************************************************

* Column 1 
/* Controlling for Performance & Corruption (FEs) */
xi: cgmreg trust_local_council ln_export_area $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
scalar coeff_dist=_b[ln_export_area]
matrix table9[1,1]=scalar(coeff_dist)
matrix V=e(V)
matrix table9[2,1]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix table9[5,1]=scalar(n_obs)
scalar r2=e(r2)
matrix table9[8,1]=scalar(r2)

** Point estimate without additional control(s) **
xi: cgmreg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(local_council_performance)~=1 & missing(corrupt_local_council)~=1 & missing(council_listen)~=1, cluster(murdock_name district)
scalar coeff_dist=_b[ln_export_area]
matrix t9nocontrols[1,1]=scalar(coeff_dist)
matrix V=e(V)
matrix t9nocontrols[2,1]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t9nocontrols[5,1]=scalar(n_obs)
scalar r2=e(r2)
matrix t9nocontrols[8,1]=scalar(r2)

* Column 2
/* Controlling for All - Add public goods */
xi: cgmreg trust_local_council ln_export_area $publicgoods $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
scalar coeff_dist=_b[ln_export_area]
matrix table9[1,2]=scalar(coeff_dist)
matrix V=e(V)
matrix table9[2,2]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix table9[5,2]=scalar(n_obs)
scalar r2=e(r2)
matrix table9[8,2]=scalar(r2)

** Point estimate without additional control(s) **
xi: cgmreg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(local_council_performance)~=1 & missing(corrupt_local_council)~=1 & missing(council_listen)~=1 & missing(school_present)!=1 & missing(electricity_present)!=1 & missing(piped_water_present)!=1 & missing(sewage_present)!=1 & missing(health_clinic_present)!=1, cluster(murdock_name district)
scalar coeff_dist=_b[ln_export_area]
matrix t9nocontrols[1,2]=scalar(coeff_dist)
matrix V=e(V)
matrix t9nocontrols[2,2]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t9nocontrols[5,2]=scalar(n_obs)
scalar r2=e(r2)
matrix t9nocontrols[8,2]=scalar(r2)

** Need to get number of clusters (CGM does not report this properly) ***
/* Controlling for Performance & Corruption (FEs) */
xi: reg trust_local_council ln_export_area $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table9[6,1]=scalar(ethn)
matrix t9nocontrols[6,1]=scalar(ethn)
xi: reg trust_local_council ln_export_area $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar dist=e(N_clust)
matrix table9[7,1]=scalar(dist)
matrix t9nocontrols[7,1]=scalar(dist)
/* Controlling for All - Add public goods */
xi: reg trust_local_council ln_export_area $publicgoods $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table9[6,2]=scalar(ethn)
matrix t9nocontrols[6,2]=scalar(ethn)
xi: reg trust_local_council ln_export_area $publicgoods $qualitylocalgovt $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar dist=e(N_clust)
matrix table9[7,2]=scalar(dist)
matrix t9nocontrols[7,2]=scalar(dist)

*********************************************
*** Test #2: Inter-Group Trust (Cols 3-5) ***
*********************************************

/*** Controlling for slave export exposure of those in the town ***/
xi: cgmreg trust_nationals ln_export_area townvill_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
predict hat if e(sample), xb
scalar coeff_dist=_b[ln_export_area]
matrix table9[1,3]=scalar(coeff_dist)
matrix V=e(V)
matrix table9[2,3]=sqrt(V[1,1])
scalar coeff_nonethn=_b[townvill_nonethnic_mean_exports]
matrix table9[3,3]=scalar(coeff_nonethn)
matrix table9[4,3]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table9[5,3]=scalar(n_obs)
scalar r2=e(r2)
matrix table9[8,3]=scalar(r2)

** Point estimate without additional control(s) **
xi: cgmreg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(murdock_name district)
drop hat
scalar coeff_dist=_b[ln_export_area]
matrix t9nocontrols[1,3]=scalar(coeff_dist)
matrix V=e(V)
matrix t9nocontrols[2,3]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t9nocontrols[5,3]=scalar(n_obs)
scalar r2=e(r2)
matrix t9nocontrols[8,3]=scalar(r2)


/*** Controlling for slave export exposure of those in the district ***/
xi: cgmreg trust_nationals ln_export_area district_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
predict hat if e(sample), xb
scalar coeff_dist=_b[ln_export_area]
matrix table9[1,4]=scalar(coeff_dist)
matrix V=e(V)
matrix table9[2,4]=sqrt(V[1,1])
scalar coeff_nonethn=_b[district_nonethnic_mean_exports]
matrix table9[3,4]=scalar(coeff_nonethn)
matrix table9[4,4]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table9[5,4]=scalar(n_obs)
scalar r2=e(r2)
matrix table9[8,4]=scalar(r2)

** Point estimate without additional control(s) **
xi: cgmreg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(murdock_name district)
drop hat
scalar coeff_dist=_b[ln_export_area]
matrix t9nocontrols[1,4]=scalar(coeff_dist)
matrix V=e(V)
matrix t9nocontrols[2,4]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t9nocontrols[5,4]=scalar(n_obs)
scalar r2=e(r2)
matrix t9nocontrols[8,4]=scalar(r2)

/*** Controlling for slave export exposure of those in the region ***/
xi: cgmreg trust_nationals ln_export_area region_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name district)
predict hat if e(sample), xb
scalar coeff_dist=_b[ln_export_area]
matrix table9[1,5]=scalar(coeff_dist)
matrix V=e(V)
matrix table9[2,5]=sqrt(V[1,1])
scalar coeff_nonethn=_b[region_nonethnic_mean_exports]
matrix table9[3,5]=scalar(coeff_nonethn)
matrix table9[4,5]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table9[5,5]=scalar(n_obs)
scalar r2=e(r2)
matrix table9[8,5]=scalar(r2)

** Point estimate without additional control(s) **
xi: cgmreg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(murdock_name district)
drop hat
scalar coeff_dist=_b[ln_export_area]
matrix t9nocontrols[1,5]=scalar(coeff_dist)
matrix V=e(V)
matrix t9nocontrols[2,5]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t9nocontrols[5,5]=scalar(n_obs)
scalar r2=e(r2)
matrix t9nocontrols[8,5]=scalar(r2)

** Need to get number of clusters (CGM does not report this properly) ***
*** Village ***
xi: reg trust_nationals ln_export_area townvill_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table9[6,3]=scalar(ethn)
matrix t9nocontrols[6,3]=scalar(ethn)
xi: reg trust_nationals ln_export_area townvill_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar dist=e(N_clust)
matrix table9[7,3]=scalar(dist)
matrix t9nocontrols[7,3]=scalar(dist)

*** District ***
xi: reg trust_nationals ln_export_area district_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table9[6,4]=scalar(ethn)
matrix t9nocontrols[6,4]=scalar(ethn)
xi: reg trust_nationals ln_export_area district_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar dist=e(N_clust)
matrix table9[7,4]=scalar(dist)
matrix t9nocontrols[7,4]=scalar(dist)

*** Region ***
xi: reg trust_nationals ln_export_area region_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table9[6,5]=scalar(ethn)
matrix t9nocontrols[6,5]=scalar(ethn)
xi: reg trust_nationals ln_export_area region_nonethnic_mean_exports $baseline_controls $colonial_controls ln_init_pop_density, cluster(district)
scalar dist=e(N_clust)
matrix table9[7,5]=scalar(dist)
matrix t9nocontrols[7,5]=scalar(dist)

mat list table9
mat list t9nocontrols


****************
*** Table 10 ***
****************

* Location-based exports

matrix table10=J(8,4,.)
matrix colnames table10 = trust_relatives trust_local_council trust_peopleyouknow trust_nationals
matrix rownames table10 = ethnic_export SE_ethnic location_export SE_location n_obs n_ethn n_location r2

matrix t10nocontrols=J(8,4,.)
matrix colnames t10nocontrols = trust_relatives trust_local_council trust_peopleyouknow trust_nationals
matrix rownames t10nocontrols = ethnic_export SE_ethnic location_export SE_location n_obs n_ethn n_location r2

*** Relatives Trust ***
xi: cgmreg trust_relatives ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name murdock_name)
scalar coeff_ethnic=_b[ln_export_area]
scalar coeff_location=_b[loc_ln_export_area]
matrix V=e(V)
matrix table10[1,1]=scalar(coeff_ethnic)
matrix table10[2,1]=sqrt(V[1,1])
matrix table10[3,1]=scalar(coeff_location)
matrix table10[4,1]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table10[5,1]=scalar(n_obs)
scalar r2=e(r2)
matrix table10[8,1]=scalar(r2)

predict hat if e(sample), xb
** Point estimate without additional control(s) **
xi: cgmreg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(loc_murdock_name murdock_name)
drop hat
scalar coeff_ethnic=_b[ln_export_area]
matrix V=e(V)
matrix t10nocontrols[1,1]=scalar(coeff_ethnic)
matrix t10nocontrols[2,1]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t10nocontrols[5,1]=scalar(n_obs)
scalar r2=e(r2)
matrix t10nocontrols[8,1]=scalar(r2)

*** Trust Local Council ***
xi: cgmreg trust_local_council ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name murdock_name)
scalar coeff_ethnic=_b[ln_export_area]
scalar coeff_location=_b[loc_ln_export_area]
matrix V=e(V)
matrix table10[1,2]=scalar(coeff_ethnic)
matrix table10[2,2]=sqrt(V[1,1])
matrix table10[3,2]=scalar(coeff_location)
matrix table10[4,2]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table10[5,2]=scalar(n_obs)
scalar r2=e(r2)
matrix table10[8,2]=scalar(r2)

predict hat if e(sample), xb
** Point estimate without additional control(s) **
xi: cgmreg trust_local_council ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(loc_murdock_name murdock_name)
drop hat
scalar coeff_ethnic=_b[ln_export_area]
matrix V=e(V)
matrix t10nocontrols[1,2]=scalar(coeff_ethnic)
matrix t10nocontrols[2,2]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t10nocontrols[5,2]=scalar(n_obs)
scalar r2=e(r2)
matrix t10nocontrols[8,2]=scalar(r2)


*** Trust People You Know ***
xi: cgmreg trust_peopleyouknow ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name murdock_name)
scalar coeff_ethnic=_b[ln_export_area]
scalar coeff_location=_b[loc_ln_export_area]
matrix V=e(V)
matrix table10[1,3]=scalar(coeff_ethnic)
matrix table10[2,3]=sqrt(V[1,1])
matrix table10[3,3]=scalar(coeff_location)
matrix table10[4,3]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table10[5,3]=scalar(n_obs)
scalar r2=e(r2)
matrix table10[8,3]=scalar(r2)

predict hat if e(sample), xb
** Point estimate without additional control(s) **
xi: cgmreg trust_peopleyouknow ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(loc_murdock_name murdock_name)
drop hat
scalar coeff_ethnic=_b[ln_export_area]
matrix V=e(V)
matrix t10nocontrols[1,3]=scalar(coeff_ethnic)
matrix t10nocontrols[2,3]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t10nocontrols[5,3]=scalar(n_obs)
scalar r2=e(r2)
matrix t10nocontrols[8,3]=scalar(r2)


*** Trust other people from your country ***
xi: cgmreg trust_nationals ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name murdock_name)
scalar coeff_ethnic=_b[ln_export_area]
scalar coeff_location=_b[loc_ln_export_area]
matrix V=e(V)
matrix table10[1,4]=scalar(coeff_ethnic)
matrix table10[2,4]=sqrt(V[1,1])
matrix table10[3,4]=scalar(coeff_location)
matrix table10[4,4]=sqrt(V[2,2])
scalar n_obs=e(N)
matrix table10[5,4]=scalar(n_obs)
scalar r2=e(r2)
matrix table10[8,4]=scalar(r2)

predict hat if e(sample), xb
** Point estimate without additional control(s) **
xi: cgmreg trust_nationals ln_export_area $baseline_controls $colonial_controls ln_init_pop_density if missing(hat)!=1, cluster(loc_murdock_name murdock_name)
drop hat
scalar coeff_ethnic=_b[ln_export_area]
matrix V=e(V)
matrix t10nocontrols[1,4]=scalar(coeff_ethnic)
matrix t10nocontrols[2,4]=sqrt(V[1,1])
scalar n_obs=e(N)
matrix t10nocontrols[5,4]=scalar(n_obs)
scalar r2=e(r2)
matrix t10nocontrols[8,4]=scalar(r2)


** Need to get number of clusters (CGM does not report this properly) ***
*** Relatives Trust ***
xi: reg trust_relatives ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table10[6,1]=scalar(ethn)
matrix t10nocontrols[6,1]=scalar(ethn)
xi: reg trust_relatives ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name)
scalar location=e(N_clust)
matrix table10[7,1]=scalar(location)

*** Trust Local Council ***
xi: reg trust_local_council ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table10[6,2]=scalar(ethn)
matrix t10nocontrols[6,2]=scalar(ethn)
xi: reg trust_local_council ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name)
scalar location=e(N_clust)
matrix table10[7,2]=scalar(location)

*** Trust People You Know ***
xi: reg trust_peopleyouknow ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table10[6,3]=scalar(ethn)
matrix t10nocontrols[6,3]=scalar(ethn)
xi: reg trust_peopleyouknow ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name)
scalar location=e(N_clust)
matrix table10[7,3]=scalar(location)

*** Trust Other People From Your Country ***
xi: reg trust_nationals ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
scalar ethn=e(N_clust)
matrix table10[6,4]=scalar(ethn)
matrix t10nocontrols[6,4]=scalar(ethn)
xi: reg trust_nationals ln_export_area loc_ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(loc_murdock_name)
scalar location=e(N_clust)
matrix table10[7,4]=scalar(location)

mat list table10
mat list t10nocontrols

**********************
* SUMMARY OF RESULTS *
**********************

* Summary statistics of our sample (to be compared with summary statistics of N&W)
sum age age2 male urban_dum education employment religion living_conditions district_ethnic_frac frac_ethnicity_in_district country malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum v30 v33
sum exports ln_exports export_area ln_export_area export_pop ln_export_pop

di "Table 1"
mat list table1
di "Table 2"
mat list table2
di "Table 3"
mat list table3
di "Table 4"
mat list table4
di "Table 5"
mat list table5
di "Table 6"
mat list table6
di "Table 7"
mat list table7
di "Table 8"
mat list table8
di "Table 9"
mat list table9
di "Table 9 without controls"
mat list t9nocontrols
di "Table 10"
mat list table10
di "Table 10 without Location-based Exports"
mat list t10nocontrols

* Comparing the number of ethnic groups

* TABLE 2: Trust of Relatives *

global baseline_controls "age age2 male urban_dum i.education i.employment i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.country"
global colonial_controls "malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum i.v30 v33"
xi: reg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name)
cap drop check1
predict check1, xb
keep if check1!=. & trust_relatives!=.
sort murdock_name
by murdock_name: gen counter=_n
keep if counter==1
keep murdock_name 
save "Comparison_Ethnicities", replace

use "Nunn_Wantchekon_AER_2011.dta", clear
global baseline_controls "age age2 male urban_dum i.education i.occupation i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.isocode"
global colonial_controls "malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum i.v30 v33"
global no_occupation "age age2 male urban_dum i.education i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.isocode"
xi: reg trust_relatives ln_export_area $baseline_controls, cluster(murdock_name)
cap drop check2
predict check2, xb
keep if check2!=. & trust_relatives!=.
sort murdock_name
by murdock_name: gen counter=_n
keep if counter==1
keep murdock_name

merge 1:1 murdock_name using "Comparison_Ethnicities"
qui tab murdock_name if _merge==1
di "Ethnicities used by N&W but not in our replication: " r(r)

qui tab murdock_name if _merge==2
di "Ethnicities used in our replication but not in N&W: " r(r)

qui tab murdock_name if _merge==3
di "Ethnicities used in both: " r(r)
clear

* TABLE 3: Trust of Relatives *
use "NunnWantchekon_Dataset", clear
global baseline_controls "age age2 male urban_dum i.education i.employment i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.country"
global colonial_controls "malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum i.v30 v33"
xi: reg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
cap drop check1
predict check1, xb
keep if check1!=. & trust_relatives!=.
sort murdock_name
by murdock_name: gen counter=_n
keep if counter==1
keep murdock_name 
save "Comparison_Ethnicities", replace

use "Nunn_Wantchekon_AER_2011.dta", clear
global baseline_controls "age age2 male urban_dum i.education i.occupation i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.isocode"
global colonial_controls "malaria_ecology total_missions_area explorer_contact railway_contact cities_1400_dum i.v30 v33"
global no_occupation "age age2 male urban_dum i.education i.religion i.living_conditions district_ethnic_frac frac_ethnicity_in_district i.isocode"
xi: reg trust_relatives ln_export_area $baseline_controls $colonial_controls ln_init_pop_density, cluster(murdock_name)
cap drop check2
predict check2, xb
keep if check2!=. & trust_relatives!=.
sort murdock_name
by murdock_name: gen counter=_n
keep if counter==1
keep murdock_name

merge 1:1 murdock_name using "Comparison_Ethnicities"
qui tab murdock_name if _merge==1
di "Ethnicities used by N&W but not in our replication: " r(r)

qui tab murdock_name if _merge==2
di "Ethnicities used in our replication but not in N&W: " r(r)

qui tab murdock_name if _merge==3
di "Ethnicities used in both: " r(r)

**************************************

log close
